@@ -74,13 +74,6 @@ class SuiteRequirements(Requirements):
     def reflects_fk_options(self):
         return exclusions.closed()
 
-    @property
-    def sqlalchemy_13(self):
-        return exclusions.skip_if(
-            lambda config: not util.sqla_13,
-            "SQLAlchemy 1.3 or greater required",
-        )
-
     @property
     def sqlalchemy_14(self):
         return exclusions.skip_if(
@@ -91,7 +84,7 @@ class SuiteRequirements(Requirements):
     @property
     def sqlalchemy_1x(self):
         return exclusions.skip_if(
-            lambda config: not util.sqla_1x,
+            lambda config: util.sqla_2,
             "SQLAlchemy 1.x test",
         )
 
@@ -203,7 +196,3 @@ class SuiteRequirements(Requirements):
         return exclusions.only_if(
             exclusions.BooleanPredicate(sqla_compat.has_identity)
         )
-
-    @property
-    def supports_identity_on_null(self):
-        return exclusions.closed()
