@@ -49,6 +49,7 @@ from alembic.testing import eq_ignore_whitespace
 from alembic.testing import mock
 from alembic.testing import TestBase
 from alembic.testing.fixtures import op_fixture
+from alembic.util import sqla_compat
 
 
 class AutogenRenderTest(TestBase):
@@ -1093,7 +1094,7 @@ class AutogenRenderTest(TestBase):
 
     def test_render_add_column_system(self):
         # this would never actually happen since "system" columns
-        # can't be added in any case.   Howver it will render as
+        # can't be added in any case.   However it will render as
         # part of op.CreateTableOp.
         op_obj = ops.AddColumnOp("foo", Column("xmin", Integer, system=True))
         eq_ignore_whitespace(
@@ -1982,6 +1983,27 @@ class AutogenRenderTest(TestBase):
             ")",
         )
 
+    def test_render_table_with_info(self):
+        m = MetaData()
+        t = Table(
+            "test",
+            m,
+            Column("id", Integer, primary_key=True),
+            Column("q", Integer, ForeignKey("address.id")),
+            info={"oracle_partition": "PARTITION BY ..."},
+        )
+        op_obj = ops.CreateTableOp.from_table(t)
+        eq_ignore_whitespace(
+            autogenerate.render_op_text(self.autogen_context, op_obj),
+            "op.create_table('test',"
+            "sa.Column('id', sa.Integer(), nullable=False),"
+            "sa.Column('q', sa.Integer(), nullable=True),"
+            "sa.ForeignKeyConstraint(['q'], ['address.id'], ),"
+            "sa.PrimaryKeyConstraint('id'),"
+            "info={'oracle_partition': 'PARTITION BY ...'}"
+            ")",
+        )
+
     def test_render_add_column_with_comment(self):
         op_obj = ops.AddColumnOp(
             "foo", Column("x", Integer, comment="This is a Column")
@@ -2120,7 +2142,7 @@ class AutogenRenderTest(TestBase):
 
     @config.requirements.computed_columns_api
     @testing.combinations((True,), (False,))
-    def test_render_alter_column_computed_modify_default_perisisted(
+    def test_render_alter_column_computed_modify_default_persisted(
         self, persisted
     ):
         op_obj = ops.AlterColumnOp(
@@ -2136,7 +2158,7 @@ class AutogenRenderTest(TestBase):
 
     @config.requirements.computed_columns_api
     @testing.combinations((True,), (False,))
-    def test_render_alter_column_computed_existing_default_perisisted(
+    def test_render_alter_column_computed_existing_default_persisted(
         self, persisted
     ):
         c = sa.Computed("42", persisted=persisted)
@@ -2150,15 +2172,13 @@ class AutogenRenderTest(TestBase):
             % persisted,
         )
 
-    @config.requirements.identity_columns_api
-    @testing.combinations(
+    identity_comb = testing.combinations(
         ({}, "sa.Identity(always=False)"),
         (dict(always=None), "sa.Identity(always=None)"),
         (dict(always=True), "sa.Identity(always=True)"),
         (
             dict(
                 always=False,
-                on_null=True,
                 start=2,
                 increment=4,
                 minvalue=-3,
@@ -2167,13 +2187,30 @@ class AutogenRenderTest(TestBase):
                 nomaxvalue=True,
                 cycle=True,
                 cache=42,
-                order=True,
             ),
-            "sa.Identity(always=False, on_null=True, start=2, increment=4, "
+            "sa.Identity(always=False, start=2, increment=4, "
             "minvalue=-3, maxvalue=99, nominvalue=True, nomaxvalue=True, "
-            "cycle=True, cache=42, order=True)",
+            "cycle=True, cache=42)",
+        ),
+        (
+            dict(start=42, oracle_on_null=True, oracle_order=False),
+            "sa.Identity(always=False, start=42, oracle_on_null=True, "
+            "oracle_order=False)",
+            testing.exclusions.only_if(
+                lambda: sqla_compat.identity_has_dialect_kwargs
+            ),
+        ),
+        (
+            dict(start=42, on_null=True, order=False),
+            "sa.Identity(always=False, on_null=True, start=42, order=False)",
+            testing.exclusions.only_if(
+                lambda: not sqla_compat.identity_has_dialect_kwargs
+            ),
         ),
     )
+
+    @config.requirements.identity_columns_api
+    @identity_comb
     def test_render_add_column_identity(self, kw, text):
         col = Column("x", Integer, sa.Identity(**kw))
         op_obj = ops.AddColumnOp("foo", col)
@@ -2184,29 +2221,7 @@ class AutogenRenderTest(TestBase):
         )
 
     @config.requirements.identity_columns_api
-    @testing.combinations(
-        ({}, "sa.Identity(always=False)"),
-        (dict(always=None), "sa.Identity(always=None)"),
-        (dict(always=True), "sa.Identity(always=True)"),
-        (
-            dict(
-                always=False,
-                on_null=True,
-                start=2,
-                increment=4,
-                minvalue=-3,
-                maxvalue=99,
-                nominvalue=True,
-                nomaxvalue=True,
-                cycle=True,
-                cache=42,
-                order=True,
-            ),
-            "sa.Identity(always=False, on_null=True, start=2, increment=4, "
-            "minvalue=-3, maxvalue=99, nominvalue=True, nomaxvalue=True, "
-            "cycle=True, cache=42, order=True)",
-        ),
-    )
+    @identity_comb
     def test_render_alter_column_add_identity(self, kw, text):
         op_obj = ops.AlterColumnOp(
             "foo",
