@@ -444,7 +444,7 @@ class PostgresqlOpTest(TestBase):
                 maxvalue=9999,
                 minvalue=0,
             ),
-            dict(always=False, start=3, order=True, on_null=False, cache=2),
+            dict(always=False, start=3, cache=2),
             "SET CACHE 2",
         ),
         (
@@ -797,7 +797,7 @@ class PostgresqlDefaultCompareTest(TestBase):
     def test_compare_unicode_literal(self):
         self._compare_default_roundtrip(String(), "im a default")
 
-    # TOOD: will need to actually eval() the repr() and
+    # TODO: will need to actually eval() the repr() and
     # spend more effort figuring out exactly the kind of expression
     # to use
     def _TODO_test_compare_character_str_w_singlequote(self):
@@ -1299,6 +1299,22 @@ class PostgresqlAutogenRenderTest(TestBase):
             "postgresql.JSONB(astext_type=sa.Text())",
         )
 
+    def test_jsonb_expression_in_index(self):
+        """test #1322"""
+
+        m = MetaData()
+        t = Table("tbl", m, Column("c", JSONB()))
+        idx = Index("my_idx", t.c.c["foo"].astext)
+
+        eq_ignore_whitespace(
+            autogenerate.render.render_op_text(
+                self.autogen_context,
+                ops.CreateIndexOp.from_index(idx),
+            ),
+            "op.create_index('my_idx', 'tbl', "
+            "[sa.text(\"(c ->> 'foo')\")], unique=False)",
+        )
+
     @config.requirements.nulls_not_distinct_sa
     def test_render_unique_nulls_not_distinct_constraint(self):
         m = MetaData()
